#
# spec file for package xtrans
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xtrans
Version:        1.5.1
Release:        1.1
Summary:        Library to handle network protocol transport in X
License:        MIT
Group:          Development/Libraries/X11
URL:            https://xorg.freedesktop.org/
Source:         http://xorg.freedesktop.org/archive/individual/lib/%{name}-%{version}.tar.xz
Patch0:         p_xauth.diff
Patch1:         n_unifdef-LBXPROXY_t-and-TEST_t.patch
Patch2:         u_xtrans-noarch-pkgconfig.patch
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(xorg-macros) >= 1.12
BuildRequires:  pkgconfig(xshmfence)
# Package was named xorg-x11-xtrans-devel until 12.2
# We use 7.7 for Provides/Obsoletes, since we're renaming the packages when
# X11R7.7 is in RC1, and xorg-x11-xtrans-devel was version 7.6
Provides:       xorg-x11-xtrans-devel = 7.7
Obsoletes:      xorg-x11-xtrans-devel < 7.7
BuildArch:      noarch

%description
xtrans is a library of code that is shared among various X packages to
handle network protocol transport in a modular fashion, allowing a
single place to add new transport types. It is used by the X server,
libX11, libICE, the X font server, and related components.

%prep
%setup -q
%patch -P 0
%patch -P 1 -p1 -R
%patch -P 2 -p1

%build
%configure --docdir=%{_docdir}/xtrans
make %{?_smp_mflags}

%install
%make_install

%pre
test -L usr/include/X11 && rm usr/include/X11
exit 0

%files
%license COPYING
%doc AUTHORS ChangeLog README.md
%doc doc/xtrans.xml
%{_includedir}/X11/Xtrans/
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/xtrans.m4
%{_datadir}/pkgconfig/xtrans.pc

%changelog
* Sun Oct 13 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to 1.5.1
  * gitlab CI: add xz-utils to container for "make distcheck"
  * gitlab CI: collect config.log to help diagnose failures
  * gitlab CI: add libc-dev to required packages in build container
  * LocalInitTransports: Fix -Wuseless-cast warning for getenv() call
  * SocketCreateListener: Fix -Wuseless-cast warning in bind() call
  * Clear numerous -Wsign-compare warnings from gcc 14.1
  * SocketINETConnect: return failure when malloc() fails
  * ParseAddress: return failure when strdup() fails
  * MakeAllCOTSServerListeners: Initialize temp_ciptrs
  * GetMyNetworkId: Avoid writing to NULL pointer if malloc() fails
  * GetPeerNetworkId: Avoid writing to NULL pointer if malloc() fails
  * GetPeerNetworkId: avoid calling strlen() on a NULL pointer
  * SocketOpen: avoid leak of out-of-range fd
  * is_numeric: Add TRANS_SERVER to required ifdefs
  * update .gitignore
  * TRANS(ParseAddress): Fix "assignment discards ‘const’ qualifier" warnings
  * TRANS(GetHostname): Fix "‘strncpy’ output truncated.." warning
  * Fix string length check
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Jun 10 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to 1.5.0
  xtrans is a library of code that is shared among various X packages to handle
  network protocol transport in a modular fashion, allowing a single place to
  add new transport types - but it is *not* a shared library, more like a \
  "header-only" library.  It is used by the X server, the XIM support in libX11,
  libICE, the X font server, and related components.  Because this is not a
  shared library, the changes in this release will only take effect in consumers
  that are rebuilt on a system with this release of xtrans installed.
  This release makes progress towards resolving CVE-2020-25697, reported in
  https://www.openwall.com/lists/oss-security/2020/11/09/3 .  Clients will no
  longer attempt to connect to sockets in the abstract namespace, though
  servers will still bind to them to prevent other programs binding to those
  names to intercept connections from clients using libraries built with older
  versions of libxtrans or libxcb while the servers are running.  Clients can
  also now specify a full Unix domain socket pathname to connect to, instead
  of relying on built-in defaults under /tmp.  (Note that libX11 1.4.0 and later
  relies on libxcb for making connections instead of libxtrans, so X11 protocol
  clients will get this support in an upcoming release of libxcb, and the changes
  in xtrans will only affect clients of other protocols using libxtrans, such as
  XIM, ICE, SM, and the font service protocols.)
  This release also removes support for System V UNIX platforms other than
  Solaris and the illumos family - OS'es from SCO, AT&T's Unix Systems Group,
  Novell, and NCR are no longer supported.
* Wed Sep 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add u_xtrans-noarch-pkgconfig.patch: Do not add
  libdir=/usr(lib|lib64) entry to an arch-independent pkgconfig
  file (installed to /usr/share) (boo#1109895).
* Thu Aug  8 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Own %%{_datadir}/aclocal: when we might switch to pkgconf instead
  of pkg-config, nothing in the build root is 'accidentally' owning
  this directory for us.
* Fri Mar 22 2019 Stefan Dirsch <sndirsch@suse.com>
- n_unifdef-LBXPROXY_t-and-TEST_t.patch
  * reverse apply in order to fix build of lbxproxy again ...
* Fri Mar 22 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.4.0
  * This release drops a bunch of dead code, including support
    only used by lbxproxy and pre-1.4.0 versions of libX11, as
    well as support for obsolete SysV x86 platforms. It also
    provides some bug fixes & other maintenance work.
* Tue May 30 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #320388 (bsc#1041610)
* Tue Sep 23 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.3.5:
  Here's a release of Xtrans that includes a bunch of const fixes
  and a new Listen function which the X server wants to allow
  - nolisten tcp by default.
* Fri Apr 25 2014 tobias.johannes.klausmann@mni.thm.de
- Remove superfluous Require
* Mon Mar 31 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.3.4:
  + configure: Also add -D_DEFAULT_SOURCE to .pc cflags to shut up glibc warnings
  + Increase UNIX socket buffer size
  + Cast ctype(3) function arguments to unsigned char.
  + Add missing headers for free() and strlen().
* Mon Jan 27 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.3.3:
  + xtrans.m4: replace obsolete AC_HELP_STRING
  + xtrans.m4: replace deprecated AC_HAVE_LIBRARY with AC_CHECK_LIB
  + xtrans.m4: remove AC_TYPE_SIGNAL and Imake SIGNALRETURNSINT
  + Add TransIsListening()
  + Remove unused static inlines
  + Fix alignment issues in FD passing code
  + Don't restrict FD passing to Linux & Solaris
  + Define TRANS_RECEIVED flag for transports
  + Enable systemd socket activation
* Fri Nov  8 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.3.2:
  Another round of fixes for the fd sending API's: improves portability,
  fixes build failures on BSD & Solaris when building with the new API
  disabled, and enables the new API for Solaris.
  + Add stubs for send/recv fd functions in local transports
  + Check if we need to define _XOPEN_SOURCE for struct msghdr.msg_control
  + Allow XTRANS_SEND_FDS on Solaris as well
  + Actually disable all of the FD passing code unless XTRANS_SEND_FDS is set
  + Switch to CMSG_* macros for FD passing
* Thu Nov  7 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.3.1:
  Here's a new 1.3.1 release of libXtrans. The only interesting change
  is that it now requires applications to specify that they want FD
  passing support by defining XTRANS_SEND_FDS; the X server will do that
  only on Linux. When non-Linux FD passing support is integrated, we can
  change what the X server does.
- Add upstream patch to fix build:
  + U_disable_all_of_the_FD_passing_code_unless_XTRANS_SEND_FDS_is_set.patch
* Sun Nov  3 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.3.0:
  + configure: Remove AM_MAINTAINER_MODE
  + Remove unused TLI ("STREAMSCONN") code from xtrans
  + Docs: convert function synopses to docbook funcsynopsis markup
  + autogen.sh: Implement GNOME Build API
  + Remove 'Readv' interface
  + Add APIs to send file descriptors through the network
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Tue Sep 25 2012 sndirsch@suse.com
- specfile cleanup
* Sun Apr 15 2012 vuntz@opensuse.org
- Rename source and binary package from xorg-x11-xtrans-devel to
  xtrans.
- Add Provides/Obsoletes for xorg-x11-xtrans-devel to smooth
  upgrades.
- Pass --docdir=%%{_docdir}/xtrans to configure to install
  xtrans.xml in the right doc directory, instead of
  /usr/share/doc/xtrans/).
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to xtrans 1.2.7:
  + Lot of cleanups, both from manual inspection and from automated
    static code analysis
  + Bug fixes, including:
  - fix some resource & memory leaks
  - avoid buffer overrun in SocketReopen
  + Remove decnet leftover
  + Remove SUN specific code, let solaris create .X11-pipe with
    sticky bit on
  + Documentation & build configuration improvments
- Include version of xtrans in the version of the package. For
  instance, this will now be 7.6_1.2.7.
- Add pkgconfig(xorg-macros) BuildRequires.
* Thu Mar 22 2012 jengelh@medozas.de
- Parallel build with %%_smp_mflags; strip redundant sections/tags
* Wed Jan 11 2012 sndirsch@suse.com
- fixed build on factory
- package build errors fixed
* Tue Dec 21 2010 sndirsch@novell.com
- bumped version number to 7.6
* Tue Nov  9 2010 sndirsch@novell.com
- xtrans 1.2.6
  * This minor release converts the libxtrans API documentation
    from troff to DocBook/XML and updates it for the current state
    of the code.
    It also includes some minor bug fixes, and of course, the usual
    recent collection of build configuration improvements and
    janitorial cleanups.
* Sun Apr  4 2010 sndirsch@suse.de
- xtrans 1.2.5
- adjusted p_xauth.diff
- bumped version number to 7.5
* Mon Dec 14 2009 jengelh@medozas.de
- enable parallel building
* Sat Aug  1 2009 sndirsch@suse.de
- xtrans 1.2.4
  * various fixes
- obsoletes xtrans-sig11.diff
* Thu Feb 26 2009 sndirsch@suse.de
- xtrans 1.2.3
* Sat Oct 25 2008 sndirsch@suse.de
- xtrans-sig11.diff
  * Before accessing the string it needs to be checked if the
    string isn't NULL. (Egbert Eich, bnc #419576)
* Thu Sep 11 2008 sndirsch@suse.de
- bumped release number to 7.4
* Fri Jul  4 2008 sndirsch@suse.de
- xtrans 1.2.1
  * Connection failure for abstract socket is ECONNREFUSED, not
    ENOENT.
  * LocalClose() takes a ConnInfoPtr, not an fd
  * Clear some pointer type mismatch warnings
  * Ignore mkdir() errors when creating the abstract socket.
  * Remove extraneous execute bit from .c file
  * Launchd: This functionality has been moved into xorg-server
* Thu May  8 2008 sndirsch@suse.de
- xtrans 1.2
  * Among other things, this release fixes the linux abstract
    socket support which was broken in 1.1 (fdo bug#15677). Also
    various bug fixes and win32 updates.
* Thu Mar  6 2008 sndirsch@suse.de
- xtrans 1.1
* Sat Sep 29 2007 sndirsch@suse.de
- bumped version to 7.3
* Fri Aug 24 2007 sndirsch@suse.de
- xtrans 1.0.4:
  * Fix typo in Xtranslcl.c (sprintf with size argument should be
    snprintf)
* Mon Dec 18 2006 sndirsch@suse.de
- updated to release 1.0.3
  * Makefile.am: make ChangeLog hook safer
* Sat Oct 14 2006 sndirsch@suse.de
- updated to X.Org 7.2RC1
* Thu Aug 17 2006 sndirsch@suse.de
- removed xorg-x11-xproto-devel from BuildRequires to improve
  autobuild deps
* Sat Aug  5 2006 sndirsch@suse.de
- p_xauth.diff:
  * Let X authorization be tolerant to hostname changes (Bug #98627)
* Wed Aug  2 2006 ro@suse.de
- fix setup line
* Fri Jul 28 2006 sndirsch@suse.de
- use "-fno-strict-aliasing"
* Thu Jul 27 2006 sndirsch@suse.de
- use $RPM_OPT_FLAGS
- remove existing /usr/include/X11 symlink in %%pre
* Thu Jun 22 2006 sndirsch@suse.de
- created package
